Crate lutra_compiler

Crate lutra_compiler 

Re-exports

pub use codespan::Span;

Modules

codespan
error
ir
pr
PR, or “Parser Representation” is an AST representation of parsed source code. It takes LR tokens and converts them into a more structured form which understands expressions, such as tuples & functions.
printer
Printer that converts AST to Lutra source code.
rr

Structs

CheckParams
CompileParams
The representation kind of a compiled Lutra program.
DiscoverParams
Project
Project, checked.
SourceTree
Sources used to resolve the project. All paths are relative to the project root.
SymbolInfo
Information about a symbol at a given source position.

Enums

ProgramRepr
The representation kind of a compiled Lutra program.

Functions

_test_compile_ty
bytecode_program
check
check_overlay
compile
discover
format
parse_path
project_to_types
std_source