pub struct LineNumbers {
pub line_starts: Vec<u32>,
pub length: u32,
pub mapping: HashMap<usize, CharLen>,
}Expand description
A struct which contains information about line numbers of a source file, and can convert between byte offsets that are used in the compiler and line-column pairs used in LSP.
Fields
line_starts: Vec<u32>The byte offsets of the start of each line of the source file
length: u32The total length of the source file
mapping: HashMap<usize, CharLen>A mapping of byte offsets to character length information. This is used when converting between byte indices and line-column numbers, because LSP uses UTF-16, while Rust encodes strings as UTF-8.
This only contains characters which are more than one byte in UTF-8, because one byte UTF-8 characters are one UTF-16 segment also, so no translation is needed.
We could store the whole source file here instead, however that would be quite wasteful. Most Gleam programs use only ASCII characters, meaning UTF-8 offsets are the same as UTF-16 ones. With this representation, we only need to store a few characters.
In most programs this will be empty because they will only be using ASCII characters.
Implementations
Sourceimpl LineNumbers
impl LineNumbers
pub fn new(src: &str) -> Self
Sourcepub fn line_number(&self, byte_index: u32) -> u32
pub fn line_number(&self, byte_index: u32) -> u32
Returns the 0-indexed line number of a given byte index
Sourcepub fn line_and_column_number(&self, byte_index: u32) -> LineColumn
pub fn line_and_column_number(&self, byte_index: u32) -> LineColumn
Returns the line and column of a given byte index.
Sourcepub fn byte_index_of_line_col(&self, position: LineColumn) -> u32
pub fn byte_index_of_line_col(&self, position: LineColumn) -> u32
Returns the starting byte index of a Unicode code point at a given line and column.
Sourcepub fn spans_entire_line(&self, span: &Span) -> bool
pub fn spans_entire_line(&self, span: &Span) -> bool
Checks if the given span spans an entire line (excluding the newline character itself).
Sourcepub fn span_of_range(&self, range: &Range, source_id: u16) -> Span
pub fn span_of_range(&self, range: &Range, source_id: u16) -> Span