pub enum Pointer {
External(ExternalPtr),
Binding(u32),
Parameter(ParameterPtr),
}Variants
Implementations
Sourceimpl Pointer
impl Pointer
Sourcepub fn is_external(&self) -> bool
pub fn is_external(&self) -> bool
Returns true if this is a Pointer::External, otherwise false
Sourcepub fn as_external_mut(&mut self) -> Option<&mut ExternalPtr>
pub fn as_external_mut(&mut self) -> Option<&mut ExternalPtr>
Optionally returns mutable references to the inner fields if this is a Pointer::External, otherwise None
Sourcepub fn as_external(&self) -> Option<&ExternalPtr>
pub fn as_external(&self) -> Option<&ExternalPtr>
Optionally returns references to the inner fields if this is a Pointer::External, otherwise None
Sourcepub fn into_external(self) -> Result<ExternalPtr, Pointer>
pub fn into_external(self) -> Result<ExternalPtr, Pointer>
Returns the inner fields if this is a Pointer::External, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_binding(&self) -> bool
pub fn is_binding(&self) -> bool
Returns true if this is a Pointer::Binding, otherwise false
Sourcepub fn as_binding_mut(&mut self) -> Option<&mut u32>
pub fn as_binding_mut(&mut self) -> Option<&mut u32>
Optionally returns mutable references to the inner fields if this is a Pointer::Binding, otherwise None
Sourcepub fn as_binding(&self) -> Option<&u32>
pub fn as_binding(&self) -> Option<&u32>
Optionally returns references to the inner fields if this is a Pointer::Binding, otherwise None
Sourcepub fn into_binding(self) -> Result<u32, Pointer>
pub fn into_binding(self) -> Result<u32, Pointer>
Returns the inner fields if this is a Pointer::Binding, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_parameter(&self) -> bool
pub fn is_parameter(&self) -> bool
Returns true if this is a Pointer::Parameter, otherwise false
Sourcepub fn as_parameter_mut(&mut self) -> Option<&mut ParameterPtr>
pub fn as_parameter_mut(&mut self) -> Option<&mut ParameterPtr>
Optionally returns mutable references to the inner fields if this is a Pointer::Parameter, otherwise None
Sourcepub fn as_parameter(&self) -> Option<&ParameterPtr>
pub fn as_parameter(&self) -> Option<&ParameterPtr>
Optionally returns references to the inner fields if this is a Pointer::Parameter, otherwise None
Sourcepub fn into_parameter(self) -> Result<ParameterPtr, Pointer>
pub fn into_parameter(self) -> Result<ParameterPtr, Pointer>
Returns the inner fields if this is a Pointer::Parameter, otherwise returns back the enum in the Err case of the result