pub enum DefKind {
Module(ModuleDef),
Expr(ExprDef),
Ty(TyDef),
Import(ImportDef),
Unresolved(Option<Box<DefKind>>),
}Variants
Module(ModuleDef)
Expr(ExprDef)
Ty(TyDef)
Import(ImportDef)
Unresolved(Option<Box<DefKind>>)
A definition that has not yet been resolved. Created during the first pass of the AST, must not be present in a fully resolved module structure.
Implementations
Sourceimpl DefKind
impl DefKind
Sourcepub fn as_module_mut(&mut self) -> Option<&mut ModuleDef>
pub fn as_module_mut(&mut self) -> Option<&mut ModuleDef>
Optionally returns mutable references to the inner fields if this is a DefKind::Module, otherwise None
Sourcepub fn as_module(&self) -> Option<&ModuleDef>
pub fn as_module(&self) -> Option<&ModuleDef>
Optionally returns references to the inner fields if this is a DefKind::Module, otherwise None
Sourcepub fn into_module(self) -> Result<ModuleDef, Self>
pub fn into_module(self) -> Result<ModuleDef, Self>
Returns the inner fields if this is a DefKind::Module, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_expr_mut(&mut self) -> Option<&mut ExprDef>
pub fn as_expr_mut(&mut self) -> Option<&mut ExprDef>
Optionally returns mutable references to the inner fields if this is a DefKind::Expr, otherwise None
Sourcepub fn as_expr(&self) -> Option<&ExprDef>
pub fn as_expr(&self) -> Option<&ExprDef>
Optionally returns references to the inner fields if this is a DefKind::Expr, otherwise None
Sourcepub fn into_expr(self) -> Result<ExprDef, Self>
pub fn into_expr(self) -> Result<ExprDef, Self>
Returns the inner fields if this is a DefKind::Expr, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_ty_mut(&mut self) -> Option<&mut TyDef>
pub fn as_ty_mut(&mut self) -> Option<&mut TyDef>
Optionally returns mutable references to the inner fields if this is a DefKind::Ty, otherwise None
Sourcepub fn as_ty(&self) -> Option<&TyDef>
pub fn as_ty(&self) -> Option<&TyDef>
Optionally returns references to the inner fields if this is a DefKind::Ty, otherwise None
Sourcepub fn into_ty(self) -> Result<TyDef, Self>
pub fn into_ty(self) -> Result<TyDef, Self>
Returns the inner fields if this is a DefKind::Ty, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_import_mut(&mut self) -> Option<&mut ImportDef>
pub fn as_import_mut(&mut self) -> Option<&mut ImportDef>
Optionally returns mutable references to the inner fields if this is a DefKind::Import, otherwise None
Sourcepub fn as_import(&self) -> Option<&ImportDef>
pub fn as_import(&self) -> Option<&ImportDef>
Optionally returns references to the inner fields if this is a DefKind::Import, otherwise None
Sourcepub fn into_import(self) -> Result<ImportDef, Self>
pub fn into_import(self) -> Result<ImportDef, Self>
Returns the inner fields if this is a DefKind::Import, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_unresolved(&self) -> bool
pub fn is_unresolved(&self) -> bool
Returns true if this is a DefKind::Unresolved, otherwise false
Sourcepub fn as_unresolved_mut(&mut self) -> Option<&mut Option<Box<DefKind>>>
pub fn as_unresolved_mut(&mut self) -> Option<&mut Option<Box<DefKind>>>
Optionally returns mutable references to the inner fields if this is a DefKind::Unresolved, otherwise None