pub enum Lookup {
Name(String),
Position(i64),
}Variants
Implementations
Sourceimpl Lookup
impl Lookup
Sourcepub fn as_name_mut(&mut self) -> Option<&mut String>
pub fn as_name_mut(&mut self) -> Option<&mut String>
Optionally returns mutable references to the inner fields if this is a Lookup::Name, otherwise None
Sourcepub fn as_name(&self) -> Option<&String>
pub fn as_name(&self) -> Option<&String>
Optionally returns references to the inner fields if this is a Lookup::Name, otherwise None
Sourcepub fn into_name(self) -> Result<String, Self>
pub fn into_name(self) -> Result<String, Self>
Returns the inner fields if this is a Lookup::Name, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_position(&self) -> bool
pub fn is_position(&self) -> bool
Returns true if this is a Lookup::Position, otherwise false
Sourcepub fn as_position_mut(&mut self) -> Option<&mut i64>
pub fn as_position_mut(&mut self) -> Option<&mut i64>
Optionally returns mutable references to the inner fields if this is a Lookup::Position, otherwise None
Sourcepub fn as_position(&self) -> Option<&i64>
pub fn as_position(&self) -> Option<&i64>
Optionally returns references to the inner fields if this is a Lookup::Position, otherwise None
Sourcepub fn into_position(self) -> Result<i64, Self>
pub fn into_position(self) -> Result<i64, Self>
Returns the inner fields if this is a Lookup::Position, otherwise returns back the enum in the Err case of the result