pub struct ModuleDef {
pub imports: Vec<Def>,
pub defs: IndexMap<String, Def>,
pub annotations: Vec<Anno>,
pub span_content: Option<Span>,
}Fields
imports: Vec<Def>defs: IndexMap<String, Def>annotations: Vec<Anno>span_content: Option<Span>Span covering the content of this module, i.e. the region inside the braces for inline modules, or the whole file body for file-based submodules. This excludes inner doc comments or annotations.
Implementations
Sourceimpl ModuleDef
impl ModuleDef
Sourcepub fn try_get<'a, 's>(
&'a self,
steps: &'s [String],
) -> Option<(&'a Def, &'s [String])>
pub fn try_get<'a, 's>( &'a self, steps: &'s [String], ) -> Option<(&'a Def, &'s [String])>
Get definition by fully qualified ident and return remaining steps into the def.
Sourcepub fn get_mut(&mut self, ident: &Path) -> Option<&mut Def>
pub fn get_mut(&mut self, ident: &Path) -> Option<&mut Def>
Get an exclusive reference to definition by fully qualified ident.
pub fn get_module<'a>(&'a self, path: &[String]) -> Option<&'a ModuleDef>
pub fn get_module_mut(&mut self, path: &[String]) -> Option<&mut ModuleDef>
pub fn iter_defs(&self) -> impl Iterator<Item = (&String, &Def)>
pub fn iter_defs_re(&self) -> impl Iterator<Item = (Path, &Def)>
Sourcepub fn collect_unresolved(&self) -> HashSet<Path>
pub fn collect_unresolved(&self) -> HashSet<Path>
Collect all non-module def paths under this module into a set.
pub fn get_doc_at<'a>(&'a self, fq: &Path) -> Option<&'a str>
pub fn get_anno_at<'a, R: 'a>( &'a self, fq: &Path, matcher: impl Fn(&'a Anno) -> Option<R>, ) -> Option<R>