pub struct SourceTree { /* private fields */ }Expand description
Sources used to resolve the project. All paths are relative to the project root.
Implementations
Sourceimpl SourceTree
impl SourceTree
pub fn empty() -> Self
pub fn single(path: PathBuf, content: String) -> Self
pub fn new<I>(iter: I, root: PathBuf) -> Self
pub fn is_empty(&self) -> bool
pub fn insert(&mut self, path: PathBuf, content: String)
pub fn replace(&mut self, path: &Path, content: String) -> Option<String>
pub fn get_ids(&self) -> impl Iterator<Item = u16>
pub fn get_sources(&self) -> impl Iterator<Item = (&PathBuf, &String)>
pub fn get_by_id(&self, source_id: u16) -> Option<(&Path, &str)>
pub fn get_by_path(&self, path: &Path) -> Option<(u16, &str)>
pub fn get_source_display_paths(&self) -> impl Iterator<Item = &Path>
Sourcepub fn get_absolute_path(&self, path: impl AsRef<Path>) -> PathBuf
pub fn get_absolute_path(&self, path: impl AsRef<Path>) -> PathBuf
Converts a “project path” into an absolute path in the file-system.
Sourcepub fn get_relative_path<'a>(
&self,
absolute_path: &'a Path,
) -> Result<&'a Path, StripPrefixError>
pub fn get_relative_path<'a>( &self, absolute_path: &'a Path, ) -> Result<&'a Path, StripPrefixError>
Converts an absolute path into a path relative to the root. Not that this is not relative to “project dir”.
Sourcepub fn get_project_dir(&self) -> &Path
pub fn get_project_dir(&self) -> &Path
Returns project dir: the directory in which the project files reside. For example,
- if root is
/some_path/project/, then that is also the project dir, - if root is
/some_path/my_file.lt, then project dir is/some_path/.
Sourcepub fn get_display_path<'a>(&'a self, path: &'a Path) -> Option<&'a Path>
pub fn get_display_path<'a>(&'a self, path: &'a Path) -> Option<&'a Path>
Converts a path (either absolute or relative to project root) into a “display path”, which is path relative to “project dir”. This is equivalent to “relative path”, except for single-file projects, where root is a file and “project dir” is its parent directory.