Re-exports
pub use codespan::Span;
Modules
- codespan
- error
- ir
- pr
- PR, or “Parser Representation” is an AST representation of parsed source code. It takes LR tokens and converts them into a more structured form which understands expressions, such as tuples & functions.
- printer
- Printer that converts AST to Lutra source code.
- rr
Structs
- Check
Params - Compile
Params - The representation kind of a compiled Lutra program.
- Discover
Params - Project
- Project, checked.
- Source
Tree - Sources used to resolve the project. All paths are relative to the project root.
- Symbol
Info - Information about a symbol at a given source position.
Enums
- Program
Repr - The representation kind of a compiled Lutra program.